[Libreoffice-commits] core.git: 2 commits - qadevOOo/tests sal/osl sc/qa sc/source sd/source sfx2/source slideshow/source svtools/source test/source

Andrea Gelmini (via logerrit) logerrit at kemper.freedesktop.org
Tue Sep 10 12:18:36 UTC 2019


 qadevOOo/tests/java/ifc/drawing/_XShape.java                         |    2 -
 qadevOOo/tests/java/ifc/io/_XMarkableStream.java                     |    4 +-
 qadevOOo/tests/java/ifc/lang/_XSingleServiceFactory.java             |    4 +-
 qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetFactory.java     |    2 -
 qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetStubFactory.java |    2 -
 qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetFactory.java     |    2 -
 qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java |    2 -
 qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java     |    2 -
 qadevOOo/tests/java/mod/_invocation/uno/Invocation.java              |    2 -
 sal/osl/unx/file_url.cxx                                             |    2 -
 sc/qa/unit/ucalc_formula.cxx                                         |   16 +++++-----
 sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx                 |    4 +-
 sc/source/ui/view/gridwin.cxx                                        |    2 -
 sc/source/ui/view/gridwin2.cxx                                       |    2 -
 sd/source/ui/slidesorter/inc/model/SlideSorterModel.hxx              |    2 -
 sfx2/source/doc/objcont.cxx                                          |    2 -
 slideshow/source/engine/shapes/drawshape.hxx                         |    2 -
 slideshow/source/engine/shapes/gdimtftools.hxx                       |    2 -
 svtools/source/contnr/fileview.cxx                                   |    2 -
 test/source/sheet/xsheetoutline.cxx                                  |    8 ++---
 20 files changed, 33 insertions(+), 33 deletions(-)

New commits:
commit 0c234a60ae31c2404dfec9d09cc79a1a5c4558fd
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Tue Sep 10 10:37:53 2019 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue Sep 10 14:18:04 2019 +0200

    Fix typos
    
    Change-Id: I79f87f033eeb67d1750bb595d311d74ef3db6ce9
    Reviewed-on: https://gerrit.libreoffice.org/78795
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Jenkins

diff --git a/sal/osl/unx/file_url.cxx b/sal/osl/unx/file_url.cxx
index 75c058735c06..043199ae9522 100644
--- a/sal/osl/unx/file_url.cxx
+++ b/sal/osl/unx/file_url.cxx
@@ -368,7 +368,7 @@ oslFileError osl_getSystemPathFromFileURL_Ex(
 namespace
 {
 
-    /** Helper function, return a pinter to the final '\0'
+    /** Helper function, return a pointer to the final '\0'
         of a string
     */
 
diff --git a/sc/qa/unit/ucalc_formula.cxx b/sc/qa/unit/ucalc_formula.cxx
index a82f456f2d28..55749266ffb5 100644
--- a/sc/qa/unit/ucalc_formula.cxx
+++ b/sc/qa/unit/ucalc_formula.cxx
@@ -7805,7 +7805,7 @@ void Test::testFuncGCD()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of GCD for failed", 10.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetValue(0, 0, 0, -2.0); // A1
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(0, 0, 0, "a"); // A1
     aVal = m_pDoc->GetString(aPos);
@@ -7816,7 +7816,7 @@ void Test::testFuncGCD()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of GCD for failed", 0.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetValue(0, 1, 0, -12.0); // B1
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for a matrix with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for a matrix with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetValue(0, 0, 0, 15.0); // A1
     m_pDoc->SetValue(0, 1, 0, 0.0); // B1
@@ -7854,7 +7854,7 @@ void Test::testFuncGCD()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of GCD for failed", 150.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetString(aPos, "=GCD({-3;6;9})");
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for an array with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for an array with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(aPos, "=GCD({\"a\";6;9})");
     aVal = m_pDoc->GetString(aPos);
@@ -7868,7 +7868,7 @@ void Test::testFuncGCD()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of GCD for failed", 150.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetString(aPos,"=GCD({3;6;9};{3;-6;9})");
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for an array with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("GCD should return Err:502 for an array with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(aPos, "=GCD({3;6;9};{\"a\";6;9})");
     aVal = m_pDoc->GetString(aPos);
@@ -7903,7 +7903,7 @@ void Test::testFuncLCM()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of LCM for failed", 10.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetValue(0, 0, 0, -2.0); // A1
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(0, 0, 0, "a"); // A1
     aVal = m_pDoc->GetString(aPos);
@@ -7914,7 +7914,7 @@ void Test::testFuncLCM()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of GCD for failed", 1.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetValue(0, 1, 0, -12.0); // B1
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for a matrix with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for a matrix with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetValue(0, 0, 0, 15.0); // A1
     m_pDoc->SetValue(0, 1, 0, 0.0); // A2
@@ -7951,7 +7951,7 @@ void Test::testFuncLCM()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of LCM for failed", 0.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetString(aPos, "=LCM({-3;6;9})");
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for an array with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for an array with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(aPos, "=LCM({\"a\";6;9})");
     aVal = m_pDoc->GetString(aPos);
@@ -7965,7 +7965,7 @@ void Test::testFuncLCM()
     CPPUNIT_ASSERT_EQUAL_MESSAGE("Calculation of LCM for failed", 0.0, m_pDoc->GetValue(aPos));
     m_pDoc->SetString(aPos,"=LCM({3;6;9};{3;-6;9})");
     aVal = m_pDoc->GetString(aPos);
-    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for an array with values less then 0",
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("LCM should return Err:502 for an array with values less than 0",
             OUString("Err:502"), aVal);
     m_pDoc->SetString(aPos, "=LCM({3;6;9};{\"a\";6;9})");
     aVal = m_pDoc->GetString(aPos);
diff --git a/sc/source/ui/view/gridwin.cxx b/sc/source/ui/view/gridwin.cxx
index c2ceabd35c77..dab34195c1cf 100644
--- a/sc/source/ui/view/gridwin.cxx
+++ b/sc/source/ui/view/gridwin.cxx
@@ -5208,7 +5208,7 @@ bool ScGridWindow::GetEditUrl( const Point& rPos,
 
     std::shared_ptr<ScFieldEditEngine> pEngine = createEditEngine(pDocSh, *pPattern);
 
-    MapMode aEditMode = pViewData->GetLogicMode(eWhich);            // without draw scaleing
+    MapMode aEditMode = pViewData->GetLogicMode(eWhich);            // without draw scaling
     tools::Rectangle aLogicEdit = PixelToLogic( aEditRect, aEditMode );
     long nThisColLogic = aLogicEdit.Right() - aLogicEdit.Left() + 1;
     Size aPaperSize( 1000000, 1000000 );
diff --git a/sc/source/ui/view/gridwin2.cxx b/sc/source/ui/view/gridwin2.cxx
index ebb73fe891ae..dcbf78acdaf3 100644
--- a/sc/source/ui/view/gridwin2.cxx
+++ b/sc/source/ui/view/gridwin2.cxx
@@ -988,7 +988,7 @@ void ScGridWindow::PagebreakMove( const MouseEvent& rMEvt, bool bUp )
                     }
                     if ( bGrow )
                     {
-                        // change last break to hard, and change scaleing
+                        // change last break to hard, and change scaling
                         bool bManualBreak(rDoc.HasColBreak(static_cast<SCCOL>(nPagebreakPrev), nTab) & ScBreakType::Manual);
                         if ( static_cast<SCCOL>(nPagebreakPrev) > aPagebreakSource.aStart.Col() && !bManualBreak )
                         {
diff --git a/sd/source/ui/slidesorter/inc/model/SlideSorterModel.hxx b/sd/source/ui/slidesorter/inc/model/SlideSorterModel.hxx
index 5e9270668978..4773c2c2d10d 100644
--- a/sd/source/ui/slidesorter/inc/model/SlideSorterModel.hxx
+++ b/sd/source/ui/slidesorter/inc/model/SlideSorterModel.hxx
@@ -94,7 +94,7 @@ public:
             it is created.  When <FALSE/> then an empty reference is
             returned for missing descriptors.
         @return
-            When the given index is not valid, i.e. lower then zero or
+            When the given index is not valid, i.e. lower than zero or
             larger than or equal to the number of pages then an empty
             reference is returned. Note that the page count may change
             between calls to GetPageCount() and GetPageDescriptor().
diff --git a/sfx2/source/doc/objcont.cxx b/sfx2/source/doc/objcont.cxx
index 87f44dcf596e..ecc131177fb9 100644
--- a/sfx2/source/doc/objcont.cxx
+++ b/sfx2/source/doc/objcont.cxx
@@ -256,7 +256,7 @@ void SfxObjectShell::UpdateTime_Impl(
         }
         else if (nDays<=31)
         {
-            // If time of working without save greater then 1 month (!)...
+            // If time of working without save greater than 1 month (!)...
             // we add 0 to aOldTime!
 
             // If 1 or up to 31 days between now and last editing - calculate time indirectly.
diff --git a/slideshow/source/engine/shapes/drawshape.hxx b/slideshow/source/engine/shapes/drawshape.hxx
index 88cc9a264293..c93f0338f76c 100644
--- a/slideshow/source/engine/shapes/drawshape.hxx
+++ b/slideshow/source/engine/shapes/drawshape.hxx
@@ -76,7 +76,7 @@ namespace slideshow
                 When true, the source of the shape metafile might be a
                 foreign application. The metafile is checked against
                 unsupported content, and, if necessary, returned as a
-                pre-rendererd bitmap.
+                pre-rendered bitmap.
              */
             static DrawShapeSharedPtr create(
                 const css::uno::Reference< css::drawing::XShape >&    xShape,
diff --git a/slideshow/source/engine/shapes/gdimtftools.hxx b/slideshow/source/engine/shapes/gdimtftools.hxx
index 813c557bee81..c0c64e5f4efc 100644
--- a/slideshow/source/engine/shapes/gdimtftools.hxx
+++ b/slideshow/source/engine/shapes/gdimtftools.hxx
@@ -46,7 +46,7 @@ namespace slideshow
             MTF_LOAD_NONE = 0,
             /// the source of the metafile might be a foreign
             /// application. The metafile is checked against unsupported
-            /// content, and, if necessary, returned as a pre-rendererd
+            /// content, and, if necessary, returned as a pre-rendered
             /// bitmap.
             MTF_LOAD_FOREIGN_SOURCE = 2,
             /// retrieve a meta file for the page background only
diff --git a/svtools/source/contnr/fileview.cxx b/svtools/source/contnr/fileview.cxx
index 4c979935d108..52f07527687c 100644
--- a/svtools/source/contnr/fileview.cxx
+++ b/svtools/source/contnr/fileview.cxx
@@ -1729,7 +1729,7 @@ static bool                     gbAscending = true;
 static sal_Int16                gnColumn = COLUMN_TITLE;
 static const CollatorWrapper*   pCollatorWrapper = nullptr;
 
-/* this function returns true, if aOne is less then aTwo
+/* this function returns true, if aOne is less than aTwo
 */
 static bool CompareSortingData_Impl( std::unique_ptr<SortingData_Impl> const & aOne, std::unique_ptr<SortingData_Impl> const & aTwo )
 {
commit b86ab7eb8b14b877c93be23bfc944e629e080573
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Tue Sep 10 10:36:33 2019 +0200
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Tue Sep 10 14:17:49 2019 +0200

    Fix typos
    
    Change-Id: I263a4348774051626f57547f3fdab00a18a92f75
    Reviewed-on: https://gerrit.libreoffice.org/78792
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>
    Tested-by: Jenkins

diff --git a/qadevOOo/tests/java/ifc/drawing/_XShape.java b/qadevOOo/tests/java/ifc/drawing/_XShape.java
index 03b3132f95aa..8f6b5d791e23 100644
--- a/qadevOOo/tests/java/ifc/drawing/_XShape.java
+++ b/qadevOOo/tests/java/ifc/drawing/_XShape.java
@@ -132,7 +132,7 @@ public class _XShape extends MultiMethodTest {
         log.println("Expected: "+sNew.Height+";"+sNew.Width);
         log.println("Getting: "+gSize.Height+";"+gSize.Width);
 
-        //errors in calculation from points/twips less then 1 are acceptable
+        //errors in calculation from points/twips less than 1 are acceptable
         result &= (sNew.Height-gSize.Height <= 2) && (sNew.Width-gSize.Width <= 2);
 
         if (result && ((sNew.Height-gSize.Height != 0) || (sNew.Width-gSize.Width != 0))){
diff --git a/qadevOOo/tests/java/ifc/io/_XMarkableStream.java b/qadevOOo/tests/java/ifc/io/_XMarkableStream.java
index d4cb74ecc7b4..8c088873918b 100644
--- a/qadevOOo/tests/java/ifc/io/_XMarkableStream.java
+++ b/qadevOOo/tests/java/ifc/io/_XMarkableStream.java
@@ -173,11 +173,11 @@ public class _XMarkableStream extends MultiMethodTest {
             int offset = oObj.offsetToMark(mark);
             res = offset == 0;
         } catch(com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Couldn't get offser to mark");
+            log.println("Couldn't get offset to mark");
             e.printStackTrace(log);
             res = false;
         } catch(com.sun.star.io.IOException e) {
-            log.println("Couldn't get offser to mark");
+            log.println("Couldn't get offset to mark");
             e.printStackTrace(log);
             res = false;
         }
diff --git a/qadevOOo/tests/java/ifc/lang/_XSingleServiceFactory.java b/qadevOOo/tests/java/ifc/lang/_XSingleServiceFactory.java
index 06910de2e520..da039308ce4e 100644
--- a/qadevOOo/tests/java/ifc/lang/_XSingleServiceFactory.java
+++ b/qadevOOo/tests/java/ifc/lang/_XSingleServiceFactory.java
@@ -42,7 +42,7 @@ import com.sun.star.uno.UnoRuntime;
 *   has <code>Object[]</code> type. This relation is used as
 *   a parameter for <code>createInstanceWithArguments</code>
 *   method call. If this relation doesn't exist test pass
-*   zerro length array as argument. </li>
+*   zero length array as argument. </li>
 *  <li> <code>'XSingleServiceFactory.MustSupport'</code> <b>(optional)</b>:
 *   of type <code>java.lang.Class[]</code>. This is an array of UNO
 *   interface classes which must be supported by created instance.
@@ -114,7 +114,7 @@ public class _XSingleServiceFactory extends MultiMethodTest {
 
     /**
     * Calls the method and checks the value returned. If relation
-    * with method argument doesn't exist new zerro length array
+    * with method argument doesn't exist new zero length array
     * is created. <p>
     * Has <b>OK</b> status if non null value is returned.
     * If the relation exists which specifies required interfaces
diff --git a/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetFactory.java b/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetFactory.java
index b958e0c59b7c..d3174d926703 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetFactory.java
@@ -69,7 +69,7 @@ public class _XCachedContentResultSetFactory extends MultiMethodTest {
     * of rows from result set created and its stub are retrieved
     * using their static representations and comared. <p>
     * Has <b>OK</b> status if numbers of rows are equal and they are
-    * greater then 0 (because JAR file contains at least one entry).
+    * greater than 0 (because JAR file contains at least one entry).
     */
     public void _createCachedContentResultSet() {
         boolean result = true ;
diff --git a/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetStubFactory.java b/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetStubFactory.java
index bbb66d1943d8..90f3d4688a35 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetStubFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XCachedContentResultSetStubFactory.java
@@ -67,7 +67,7 @@ public class _XCachedContentResultSetStubFactory extends MultiMethodTest {
     * of rows in cached result set created and its source set are retrieved
     * and comared. <p>
     * Has <b>OK</b> status if numbers of rows are equal and they are
-    * greater then 0 (because JAR file contains at least one entry).
+    * greater than 0 (because JAR file contains at least one entry).
     */
     public void _createCachedContentResultSetStub() {
         boolean result = true ;
diff --git a/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetFactory.java b/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetFactory.java
index 814f4a9436f3..06dc4974f4cf 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetFactory.java
@@ -70,7 +70,7 @@ public class _XCachedDynamicResultSetFactory extends MultiMethodTest {
     * of rows from result set created and its stub are retrieved
     * using their static representations and comared. <p>
     * Has <b>OK</b> status if numbers of rows are equal and they are
-    * greater then 0 (because JAR file contains at least one entry).
+    * greater than 0 (because JAR file contains at least one entry).
     */
     public void _createCachedDynamicResultSet() {
         boolean result = true ;
diff --git a/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java b/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java
index ac505faf4435..54eef94be428 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XCachedDynamicResultSetStubFactory.java
@@ -71,7 +71,7 @@ public class _XCachedDynamicResultSetStubFactory extends MultiMethodTest {
     * of rows from result set stub created and its source set are retrieved
     * using their static representations and compared. <p>
     * Has <b>OK</b> status if numbers of rows are equal and they are
-    * greater then 0 (because JAR file contains at least one entry).
+    * greater than 0 (because JAR file contains at least one entry).
     */
     public void _createCachedDynamicResultSetStub() {
         boolean result = true ;
diff --git a/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java b/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java
index 54f49ab310ce..588a05129adb 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XSortedDynamicResultSetFactory.java
@@ -64,7 +64,7 @@ public class _XSortedDynamicResultSetFactory extends MultiMethodTest {
      * a dynamic result set is to be created. It is created by
      * retrieving content list from JAR archive.
      * Has <b>OK</b> status if numbers of rows are equal and they are
-     * greater then 0 (because JAR file contains at least one entry).
+     * greater than 0 (because JAR file contains at least one entry).
      */
     public void _createSortedDynamicResultSet() {
         boolean result = true ;
diff --git a/qadevOOo/tests/java/mod/_invocation/uno/Invocation.java b/qadevOOo/tests/java/mod/_invocation/uno/Invocation.java
index 92c765920fd4..d83a2f927563 100644
--- a/qadevOOo/tests/java/mod/_invocation/uno/Invocation.java
+++ b/qadevOOo/tests/java/mod/_invocation/uno/Invocation.java
@@ -53,7 +53,7 @@ public class Invocation extends TestCase {
     *   has <code>Object[]</code> type. This relation is used as
     *   a parameter for <code>createInstanceWithArguments</code>
     *   method call. If this relation doesn't exist test pass
-    *   zerro length array as argument. Here
+    *   zero length array as argument. Here
     *   <code>com.sun.star.io.Pipe</code> instance is passed.</li>
     *  <li> <code>'XSingleServiceFactory.MustSupport'</code> :
     *   for interface {@link _ifc.lang.XSingleServiceFactory}.
diff --git a/test/source/sheet/xsheetoutline.cxx b/test/source/sheet/xsheetoutline.cxx
index 5467995a8721..e8d829b8d1c3 100644
--- a/test/source/sheet/xsheetoutline.cxx
+++ b/test/source/sheet/xsheetoutline.cxx
@@ -139,7 +139,7 @@ void XSheetOutline::testShowLevel()
 
     aSheetOutline->showLevel(2, table::TableOrientation_COLUMNS);
 
-    std::cout << " verifiy showLevel col apres" << getVisibleAdress(aSheet, "OutlineSheet.A1:Z30") << std::endl;
+    std::cout << " verify showLevel col apres" << getVisibleAdress(aSheet, "OutlineSheet.A1:Z30") << std::endl;
 
     // verify that level 2 and level 1 are shown --> column 0..3 & column 22..26
     // level 3 & 4 are hidden --> column 4..19
@@ -161,18 +161,18 @@ void XSheetOutline::testShowLevel()
     aSheetOutline->showDetail(getAddressFromRangeString(rowLevel1));
     aSheetOutline->showDetail(getAddressFromRangeString(rowLevel2));
 
-    std::cout << " verifiy showLevel row avant" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
+    std::cout << " verify showLevel row avant" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
 
     aSheetOutline->hideDetail(aLevel1);
     aSheetOutline->hideDetail(aLevel2);
     aSheetOutline->hideDetail(aLevel3);
     aSheetOutline->hideDetail(aLevel4);
 
-    std::cout << " verifiy showLevel row juste avant" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
+    std::cout << " verify showLevel row juste avant" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
 
     aSheetOutline->showLevel(2, table::TableOrientation_ROWS);
 
-    std::cout << " verifiy showLevel row apres" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
+    std::cout << " verify showLevel row apres" << OUStringToOString(getVisibleAdress("OutlineSheet.A1:Z30"), RTL_TEXTENCODING_UTF8).getStr() << std::endl;
 
     // verify rows visible 0..3 & 24..29
     // verfiy rows hidden 4..23


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx b/sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx
index be603d6f3108..58db4cadcd4a 100644
--- a/sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx
+++ b/sc/source/ui/Accessibility/AccessibleSpreadsheet.cxx
@@ -197,11 +197,11 @@ bool ScAccessibleSpreadsheet::CalcScRangeListDifferenceMax(ScRangeList *pSrc,ScR
     int nSize =0;
     if (pDest->GetCellCount() == 0)//if the Dest Rang List is empty
     {
-        if (pSrc->GetCellCount() > sal_uInt32(nMax))//if the Src Cell count is greater then  nMax
+        if (pSrc->GetCellCount() > sal_uInt32(nMax))//if the Src Cell count is greater than  nMax
         {
             return true;
         }
         //now the cell count is less then nMax
         vecRet.reserve(10);
         size_t nSrcSize = pSrc->size();
         for (size_t i = 0; i < nSrcSize; ++i)
@@ -197,11 +197,11 @@ bool ScAccessibleSpreadsheet::CalcScRangeListDifferenceMax(ScRangeList *pSrc,ScR
             return true;
         }
-        //now the cell count is less then nMax
+        //now the cell count is less than nMax
         vecRet.reserve(10);
         size_t nSrcSize = pSrc->size();